@@ -79,109 +79,84 @@ class Api(snappi.Api):
 
                 # Configure duration and initialize the transmit mode using rate and duration info
                 mode = SetConfig.set_duration(duration=f['duration'], pps=pps, bps=bps, percent=percent)
-                
-                # duration = f['duration']
-                # if duration['choice'] == 'fixed_packets':
-
-                #     mode = STLTXSingleBurst(
-                #         total_pkts=duration['fixed_packets']['packets'], 
-                #         pps=pps, bps_L2=bps, percentage=percent
-                #     )
-
-                # elif duration['choice'] == 'fixed_seconds':
-
-                #     raise STLError('T-Rex does not support fixed_seconds duration option')
-
-                # elif duration['choice'] == 'continuous':
-                    
-                #     mode = STLTXCont(pps=pps, bps_L2=bps, percentage=percent)
-
-                # elif duration['choice'] == 'burst':
-
-                #     mode = STLTXMultiBurst(
-                #         pkts_per_burst=duration['burst']['packets'],
-                #         ibg=duration['burst']['gap'],
-                #         count=duration['burst']['bursts'],
-                #         pps=pps, bps_L2=bps, percentage=percent
-                #     )
-
-                # else:
-                #     raise STLError('Invalid duration option')
 
                 # Parse config all packet headers. Creates a Scapy packet with provided packet headers
-                layerCnt = {} # Counts the occurrences of each layer
-                layers = [] # Keeps track of all of the layers in order
-                pkt_headers = []
-                for i, header in enumerate(f['packet']):
+                pkt_headers, headerCmds = SetConfig.set_packet_headers(f['packet'])
+                vmCmds += headerCmds
+                
+                # layerCnt = {} # Counts the occurrences of each layer
+                # layers = [] # Keeps track of all of the layers in order
+                # pkt_headers = []
+                # for i, header in enumerate(f['packet']):
 
-                    # ETHERNET HEADER FIELDS CONFIGURATION
-                    if header['choice'] == 'ethernet':
-                        pkt_headers.append(Ether())
-                        layers.append('Ether')
-                        layerCnt['Ether'] = layerCnt['Ether']+1 if 'Ether' in layerCnt else 1
+                #     # ETHERNET HEADER FIELDS CONFIGURATION
+                #     if header['choice'] == 'ethernet':
+                #         pkt_headers.append(Ether())
+                #         layers.append('Ether')
+                #         layerCnt['Ether'] = layerCnt['Ether']+1 if 'Ether' in layerCnt else 1
 
-                        if 'src' in header['ethernet']:
-                            vmCmds += valueoptions.getMACValueCmds(
-                                'Ethernet', layerCnt['Ether'], header['ethernet']['src'], 'src', 0
-                            )
+                #         if 'src' in header['ethernet']:
+                #             vmCmds += valueoptions.getMACValueCmds(
+                #                 'Ethernet', layerCnt['Ether'], header['ethernet']['src'], 'src', 0
+                #             )
 
-                        if 'dst' in header['ethernet']:
-                            vmCmds += valueoptions.getMACValueCmds(
-                                'Ethernet', layerCnt['Ether'], header['ethernet']['dst'], 'dst', 0
-                            )
+                #         if 'dst' in header['ethernet']:
+                #             vmCmds += valueoptions.getMACValueCmds(
+                #                 'Ethernet', layerCnt['Ether'], header['ethernet']['dst'], 'dst', 0
+                #             )
                         
                         
-                    # IPv4 HEADER FIELDS CONFIGURATION
-                    elif header['choice'] == 'ipv4':
-                        pkt_headers.append(IP())
-                        layers.append('IP')
-                        layerCnt['IP'] = layerCnt['IP']+1 if 'IP' in layerCnt else 1
+                #     # IPv4 HEADER FIELDS CONFIGURATION
+                #     elif header['choice'] == 'ipv4':
+                #         pkt_headers.append(IP())
+                #         layers.append('IP')
+                #         layerCnt['IP'] = layerCnt['IP']+1 if 'IP' in layerCnt else 1
 
-                        if 'src' in header['ipv4']:
-                            vmCmds += valueoptions.getValueCmds(
-                                'IP', layerCnt['IP'], header['ipv4']['src'], 32, 'src', 0
-                            )
+                #         if 'src' in header['ipv4']:
+                #             vmCmds += valueoptions.getValueCmds(
+                #                 'IP', layerCnt['IP'], header['ipv4']['src'], 32, 'src', 0
+                #             )
 
-                        if 'dst' in header['ipv4']:
-                            vmCmds += valueoptions.getValueCmds(
-                                'IP', layerCnt['IP'], header['ipv4']['dst'], 32, 'dst', 0
-                            )
+                #         if 'dst' in header['ipv4']:
+                #             vmCmds += valueoptions.getValueCmds(
+                #                 'IP', layerCnt['IP'], header['ipv4']['dst'], 32, 'dst', 0
+                #             )
 
                     
-                    # UDP HEADER FIELDS CONFIGURATION
-                    elif header['choice'] == 'udp':
-                        pkt_headers.append(UDP())
-                        layers.append('UDP')
-                        layerCnt['UDP'] = layerCnt['UDP']+1 if 'UDP' in layerCnt else 1
+                #     # UDP HEADER FIELDS CONFIGURATION
+                #     elif header['choice'] == 'udp':
+                #         pkt_headers.append(UDP())
+                #         layers.append('UDP')
+                #         layerCnt['UDP'] = layerCnt['UDP']+1 if 'UDP' in layerCnt else 1
 
-                        if 'src_port' in header['udp']:
-                            vmCmds += valueoptions.getValueCmds(
-                                'UDP', layerCnt['UDP'], header['udp']['src_port'], 16, 'sport', 0
-                            )
+                #         if 'src_port' in header['udp']:
+                #             vmCmds += valueoptions.getValueCmds(
+                #                 'UDP', layerCnt['UDP'], header['udp']['src_port'], 16, 'sport', 0
+                #             )
 
-                        if 'dst_port' in header['udp']:
-                            vmCmds += valueoptions.getValueCmds(
-                                'UDP', layerCnt['UDP'], header['udp']['dst_port'], 16, 'dport', 0
-                            )
+                #         if 'dst_port' in header['udp']:
+                #             vmCmds += valueoptions.getValueCmds(
+                #                 'UDP', layerCnt['UDP'], header['udp']['dst_port'], 16, 'dport', 0
+                #             )
 
-                    # TCP HEADER FIELDS CONFIGURATION
-                    elif header['choice'] == 'tcp':
-                        pkt_headers.append(TCP())
-                        layers.append('TCP')
-                        layerCnt['TCP'] = layerCnt['TCP']+1 if 'TCP' in layerCnt else 1
+                #     # TCP HEADER FIELDS CONFIGURATION
+                #     elif header['choice'] == 'tcp':
+                #         pkt_headers.append(TCP())
+                #         layers.append('TCP')
+                #         layerCnt['TCP'] = layerCnt['TCP']+1 if 'TCP' in layerCnt else 1
 
-                        if 'src_port' in header['tcp']:
-                            vmCmds += valueoptions.getValueCmds(
-                                'TCP', layerCnt['TCP'], header['tcp']['src_port'], 16, 'sport'
-                            )
+                #         if 'src_port' in header['tcp']:
+                #             vmCmds += valueoptions.getValueCmds(
+                #                 'TCP', layerCnt['TCP'], header['tcp']['src_port'], 16, 'sport'
+                #             )
 
-                        if 'dst_port' in header['tcp']:
-                            vmCmds += valueoptions.getValueCmds(
-                                'TCP', layerCnt['TCP'], header['tcp']['dst_port'], 16, 'dport'
-                            )
+                #         if 'dst_port' in header['tcp']:
+                #             vmCmds += valueoptions.getValueCmds(
+                #                 'TCP', layerCnt['TCP'], header['tcp']['dst_port'], 16, 'dport'
+                #             )
 
-                    else:
-                        raise STLError('Invalid packet header option')
+                #     else:
+                #         raise STLError('Invalid packet header option')
                 
                 #Constructs the packet base using all headers
                 pkt_base = None
